@@ -220,7 +220,7 @@ def doi2art(pm_fetch: PubMedFetcher, cr_fetch: CrossRefFetcher, doi):  # noqa:
         pmid=work.doi,
         title=work.title[0],
         abstract=work.abstract,
-        year=work.pubyear,
+        year=str(work.pubyear),
         url=work.url,
         authors_str=work.authors_str_lastfirst if work.author else "",
         journal=work.container_title[0] if work.container_title else "",
